@@ -173,6 +173,7 @@ $lang['twittersite_title'] = 'Twitter ID';
 $lang['twittersite_title_help'] = 'Your @ name. i.e @cmsms';
 $lang['googleplus_title'] = 'Google Plus profile URL';
 $lang['googleplus_title_help'] = 'Your Google Plus profile page URL. i.e https://plus.google.com/101806562165793532909/posts';
+$lang['keywordson_title'] = 'Include keywords tag';
 $lang['key_number'] = 'Number of keywords';
 $lang['key_length'] = 'Length of keywords';
 $lang['key_length_help'] = 'Minimum character length before becoming a keyword';
@@ -246,7 +247,8 @@ $lang['changelog'] = '<ul>
 <li>Version 1.9.4 21 March 2013. Added the options to choose Apple Touch and Fav icons from the website root directory.</li>
 <li>Version 1.9.6 11 April 2013. Added the option to choose robots meta and Twitter card and Google+ profile page links.</li>
 <li>Version 1.9.7 18 April 2013. Content block variables now appear in order in the description tag, appended by the content of the default Content block by default.</li>
-<li>Version 1.9.8 22 April 2013. Added support for Google Universal Analytics.</li></ul>';
+<li>Version 1.9.8 22 April 2013. Added support for Google Universal Analytics.</li>
+<li>Version 1.9.9 30 April 2013. Added the ability to disable/enable keywords tag.</li></ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
 <p>This module adds the ability to include additional Meta data, Analytics tracking code and other useful SEO information. It can also be used to generate Doctype and Head tags, replacing the entire head of your document.</p>
 <h3>How Do I Use It</h3>
